==> estateplat-common-1.2.4-20200624.075912-375-sources.jar: cn/gtmap/estateplat/model/server/core/BdcZjjl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
  * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
  * @Time 2020/4/17 8:52
  * @description 质检记录表
  */
@Table(name="bdc_zjjl")
public class BdcZjjl {
    @Id
    private String zjjlid;

    private String wiid;
    //申请类型
    private String sqlx;
    //项目编号
    private String xmbh;
    //质检人
    private String zjr;
    //质检开始日期
    private Date zjksrq;
    //质检结束日期
    private Date zjjsrq;
    //质检状态
    private String zjzt;
    //质检不合格
    private String zjbhg;
    //创建人
    private String cjr;
    //审批人
    private String spr;

    public String getZjjlid() {
        return zjjlid;
    }

    public void setZjjlid(String zjjlid) {
        this.zjjlid = zjjlid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getXmbh() {
        return xmbh;
    }

    public void setXmbh(String xmbh) {
        this.xmbh = xmbh;
    }

    public String getZjr() {
        return zjr;
    }

    public void setZjr(String zjr) {
        this.zjr = zjr;
    }

    public Date getZjksrq() {
        return zjksrq;
    }

    public void setZjksrq(Date zjksrq) {
        this.zjksrq = zjksrq;
    }

    public Date getZjjsrq() {
        return zjjsrq;
    }

    public void setZjjsrq(Date zjjsrq) {
        this.zjjsrq = zjjsrq;
    }

    public String getZjzt() {
        return zjzt;
    }

    public void setZjzt(String zjzt) {
        this.zjzt = zjzt;
    }

    public String getZjbhg() {
        return zjbhg;
    }

    public void setZjbhg(String zjbhg) {
        this.zjbhg = zjbhg;
    }

    public String getCjr() {
        return cjr;
    }

    public void setCjr(String cjr) {
        this.cjr = cjr;
    }

    public String getSpr() {
        return spr;
    }

    public void setSpr(String spr) {
        this.spr = spr;
    }
}

==> estateplat-common-1.2.4-20211027.055955-921-sources.jar: cn/gtmap/estateplat/model/server/core/BdcZjjl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
  * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
  * @Time 2020/4/17 8:52
  * @description 质检记录表
  */
@Table(name="bdc_zjjl")
public class BdcZjjl {
    @Id
    private String zjjlid;

    private String wiid;
    //申请类型
    private String sqlx;
    //项目编号
    private String xmbh;
    //质检人
    private String zjr;
    //质检开始日期
    private Date zjksrq;
    //质检结束日期
    private Date zjjsrq;
    //质检状态
    private String zjzt;
    //质检不合格
    private String zjbhg;
    //创建人
    private String cjr;
    //审批人
    private String spr;
    //推送人
    private String tsr;
    //退回原因
    private String thyy;

    public String getZjjlid() {
        return zjjlid;
    }

    public void setZjjlid(String zjjlid) {
        this.zjjlid = zjjlid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getXmbh() {
        return xmbh;
    }

    public void setXmbh(String xmbh) {
        this.xmbh = xmbh;
    }

    public String getZjr() {
        return zjr;
    }

    public void setZjr(String zjr) {
        this.zjr = zjr;
    }

    public Date getZjksrq() {
        return zjksrq;
    }

    public void setZjksrq(Date zjksrq) {
        this.zjksrq = zjksrq;
    }

    public Date getZjjsrq() {
        return zjjsrq;
    }

    public void setZjjsrq(Date zjjsrq) {
        this.zjjsrq = zjjsrq;
    }

    public String getZjzt() {
        return zjzt;
    }

    public void setZjzt(String zjzt) {
        this.zjzt = zjzt;
    }

    public String getZjbhg() {
        return zjbhg;
    }

    public void setZjbhg(String zjbhg) {
        this.zjbhg = zjbhg;
    }

    public String getCjr() {
        return cjr;
    }

    public void setCjr(String cjr) {
        this.cjr = cjr;
    }

    public String getSpr() {
        return spr;
    }

    public void setSpr(String spr) {
        this.spr = spr;
    }

    public String getTsr() {
        return tsr;
    }

    public void setTsr(String tsr) {
        this.tsr = tsr;
    }

    public String getThyy() {
        return thyy;
    }

    public void setThyy(String thyy) {
        this.thyy = thyy;
    }
}
